/*
 * SPDX-FileCopyrightText: Stone Tickle <lattis@mochiro.moe>
 * SPDX-License-Identifier: GPL-3.0-only
 */

#ifndef MUON_FUNCTIONS_DICT_H
#define MUON_FUNCTIONS_DICT_H
#include "lang/func_lookup.h"

extern const struct func_impl impl_tbl_dict[];
extern const struct func_impl impl_tbl_dict_internal[];
#endif
